@@ -6,9 +6,10 @@ use warnings;
 use strict;
 use Error::Hierarchy::Util 'load_class';
 use Class::Scaffold::Factory::Type;
+use Vim::Tag 'make_tag';
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 use base 'Class::Scaffold::Base';
@@ -108,7 +109,7 @@ sub gen_class_hash_accessor (@) {
         my $hash;   # will be cached here
 
         no strict 'refs';
-        $::PTAGS && printf "%s\t%s\t%s\n", $method, __FILE__, __LINE__+1;
+        make_tag $method, __FILE__, __LINE__+1;
         *$method = sub {
             local $DB::sub = local *__ANON__ =
                 sprintf "%s::%s", __PACKAGE__, $method
@@ -122,7 +123,7 @@ sub gen_class_hash_accessor (@) {
         # so FOO_CLASS_NAME() will return the whole every_hash
 
         $method = sprintf '%s_CLASS_NAME' => lc $prefix;
-        $::PTAGS && printf "%s\t%s\t%s\n", $method, __FILE__, __LINE__+1;
+        make_tag $method, __FILE__, __LINE__+1;
         *$method = sub {
             local $DB::sub = local *__ANON__ =
                 sprintf "%s::%s", __PACKAGE__, $method
@@ -133,7 +134,7 @@ sub gen_class_hash_accessor (@) {
         };
 
         $method = sprintf 'release_%s_class_name_hash' => lc $prefix;
-        $::PTAGS && printf "%s\t%s\t%s\n", $method, __FILE__, __LINE__+1;
+        make_tag $method, __FILE__, __LINE__+1;
         *$method = sub {
             local $DB::sub = local *__ANON__ =
                 sprintf "%s::%s", __PACKAGE__, $method
